@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: application.cpp,v 1.34 2005/03/22 05:42:53 bherger Exp $
+** $Id: application.cpp,v 1.44 2005/07/10 01:32:44 bherger Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -152,7 +152,12 @@ ApplicationWindow::ApplicationWindow()
 {
   setFont(preferences.getMainFont());
 
-  setIcon(QPixmap(XDC_icon));
+  //old, boring icon (xdc.xpm)
+  //setIcon(QPixmap(XDC_icon));
+
+  // new, fancy PNG icon
+  setIcon( QPixmap(RingDir + "xdrawchem-icon.png") );
+
   OBGetFilters();
 
   // What's This? text for top toolbar
@@ -606,6 +611,11 @@ ApplicationWindow::ApplicationWindow()
   connect( b1, SIGNAL(IncludeFile(QString)), this, 
 	   SLOT(FromRingToolbar(QString)) );
 
+  // BioTools toolbar
+  bioTools = BuildBioTools();
+  bioTools->setLabel( tr("Biochemical drawing tools") );
+  moveDockWindow(bioTools, Qt::DockRight);
+
   // menus
   QPopupMenu * file = new QPopupMenu( this );
   menuBar()->insertItem( tr("&File"), file );
@@ -708,9 +718,9 @@ ApplicationWindow::ApplicationWindow()
   fixlen_arrow = format->insertItem(tr("&Arrow - Fixed length and angle"),this,
 			      SLOT(setFixed_arrow()) );
   format->setItemChecked(fixlen_arrow, preferences.getArrow_fixed());	
-  fix_hydrogens = format->insertItem(tr("Automatically Add &hydrogens"),this,
-  		      SLOT(setFix_Hydrogens()) );
-  format->setItemChecked(fix_hydrogens, preferences.getFixHydrogens());
+  //fix_hydrogens = format->insertItem(tr("Automatically Add &hydrogens"),this,
+  //		      SLOT(setFix_Hydrogens()) );
+  //format->setItemChecked(fix_hydrogens, preferences.getFixHydrogens());
   format->insertSeparator();
   format->insertItem(tr("Set background &color"), this, 
 		     SLOT(BackgroundColor()) );
@@ -761,6 +771,7 @@ ApplicationWindow::ApplicationWindow()
   tools->insertSeparator();
   tools->insertItem(tr("Input SMILES"), this, SLOT(FromSMILES()) );
   tools->insertItem(tr("Output SMILES"), this, SLOT(ToSMILES()) );
+  tools->insertItem(tr("Output InChI"), this, SLOT(ToInChI()) );
   tools->insertSeparator();
   tools->insertItem(tr("Build 3D model of molecule"), this, SLOT(To3D()) );
   //tools->insertSeparator();
@@ -841,20 +852,28 @@ QPopupMenu *ApplicationWindow::BuildSymbolMenu() {
   p1 = QPixmap(sym_2e_xpm);
   symbollist.append(QString("sym_2e"));
   symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 5);
+  p1 = QPixmap(sym_2e_line_xpm);
+  symbollist.append(QString("sym_2e_line"));
+  symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 6);
   p1 = QPixmap(sym_ring_up_xpm);
   symbollist.append(QString("sym_ring_up"));
-  symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 6);
+  symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 7);
   p1 = QPixmap(p_orbital_xpm);
   symbollist.append(QString("p_orbital"));
-  symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 7);
+  symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 8);
   p1 = QPixmap(p_double_xpm);
   symbollist.append(QString("p_double_orbital"));
-  symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 8);
+  symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 9);
   p1 = QPixmap(bead_xpm);
   symbollist.append(QString("bead"));
-  symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 9);
+  symbolSub->insertItem( p1, this, SLOT(FromSymbolMenu(int)), 0, 10);
+
+  symbollist.append(QString("antibody"));
+
+  symbolSub->insertItem( QIconSet( QPixmap(sym_antibody) ), tr("Antibody"), this, SLOT(FromSymbolMenu(int)), 0, 11);
+
   symbollist.append(QString("newman"));
-  symbolSub->insertItem( QIconSet( QPixmap(newman_xpm) ), tr("Newman projection symbol"), this, SLOT(FromSymbolMenu(int)), 0, 10);
+  symbolSub->insertItem( QIconSet( QPixmap(newman_xpm) ), tr("Newman projection symbol"), this, SLOT(FromSymbolMenu(int)), 0, 12);
   symbolSub->insertItem( QIconSet( QPixmap(newman_anti_xpm) ), tr("Newman projection - staggered (anti)"), r, SLOT(setMode_DrawNewmanAnti()) );
   symbolSub->insertItem( QIconSet( QPixmap(newman_eclipse_xpm) ), tr("Newman projection - eclipsed"), r, SLOT(setMode_DrawNewmanGauche()) );
   return symbolSub;
@@ -872,21 +891,24 @@ QPopupMenu *ApplicationWindow::BuildArrowMenu() {
   p1 = QPixmap(arrow_bottomharpoon_xpm);
   arrowlist.append(QString("BOTTOM_HARPOON"));
   arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 2);
+  p1 = QPixmap(arrow_middle_xpm);
+  arrowlist.append(QString("MIDDLE"));
+  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 3);
   p1 = QPixmap(arrow_didnt_work_xpm);
   arrowlist.append(QString("DIDNT_WORK"));
-  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 3);
+  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 4);
   p1 = QPixmap(arrow_dash_xpm);
   arrowlist.append(QString("DASH"));
-  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 4);
+  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 5);
   p1 = QPixmap(arrow_bi1_xpm);
   arrowlist.append(QString("BI1"));
-  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 5);
+  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 6);
   p1 = QPixmap(arrow_bi2_xpm);
   arrowlist.append(QString("BI2"));
-  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 6);
+  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 7);
   p1 = QPixmap(arrow_retro_xpm);
   arrowlist.append(QString("RETRO"));
-  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 7);
+  arrowSub->insertItem( p1, this, SLOT(FromArrowMenu(int)), 0, 8);
   return arrowSub;
 }
 
@@ -1144,7 +1166,7 @@ void ApplicationWindow::load( QString fileName )
   // fix me
   // to use OpenBabel
   //
-
+  /*
   QString realFileName = fileName;
 
   QFile f(fileName);
@@ -1168,6 +1190,7 @@ void ApplicationWindow::load( QString fileName )
   filename = fileName;
   c->DeselectAll();
   r->repaint(false);
+  */
 }
 
 
@@ -1287,11 +1310,53 @@ void ApplicationWindow::savePicture()
       return;
     }
     if (pm != 0) {
-      QPixmap tosave = r->MakePixmap( fd.isTransparent() );
-      if (pm == 1) // PNG
-	was_saved = tosave.save(picfile, "PNG");
-      if (pm == 2) // BMP
-	was_saved = tosave.save(picfile, "BMP");
+      // check for "convert" (ImageMagick)
+      bool imagemagick = false;
+      QString n1, cmd1;
+      n1.setNum( getpid() );
+      n1.prepend("/tmp/");
+      cmd1 = "convert > " + n1;
+      system( cmd1.ascii() );
+
+      QFile f1( n1 );
+      f1.open(IO_ReadOnly);
+      f1.readLine(cmd1, 256);
+
+      if (cmd1.contains("ImageMagick") > 0) {
+	std::cout << "ImageMagick is present" << std::endl;
+	imagemagick = true;
+      }
+
+      cmd1 = "rm " + n1;
+      system( cmd1.ascii() );
+
+      QPixmap tosave;
+      // use "tosave" with ImageMagick to specify size
+      tosave = r->MakePixmap( fd.isTransparent() );
+      QString sizehint;
+      n1.setNum( tosave.width() );
+      sizehint = n1;
+      sizehint.append("x");
+      n1.setNum( tosave.height() );
+      sizehint.append(n1);
+      if (imagemagick) {
+	n1 = picfile;
+	n1.append(".eps");
+	r->SaveEPS(n1);
+	//cmd1 = "convert -antialias " + n1 + " " + picfile;
+	cmd1 = "convert -antialias -size " +sizehint + " " + n1 + " -resize " 
+	  + sizehint + " " + picfile;
+	system( cmd1.ascii() );
+	cmd1 = "rm " + n1;
+	system( cmd1.ascii() );
+	was_saved = true;
+      } else {
+	tosave = r->MakePixmap( fd.isTransparent() );
+	if (pm == 1) // PNG
+	  was_saved = tosave.save(picfile, "PNG");
+	if (pm == 2) // BMP
+	  was_saved = tosave.save(picfile, "BMP");
+      }
       if (was_saved)
 	statusBar()->message( tr("Saved picture file ") + picfile );
       else
@@ -1308,16 +1373,59 @@ void ApplicationWindow::savePicture()
 
 void ApplicationWindow::SavePNG() {
   bool was_saved;
-  QPixmap tosave = r->MakePixmap( ni_tflag );
-  was_saved = tosave.save(ni_savefile, "PNG");
-  if (was_saved == false) cout << "save PNG failed" << endl;
-  exit(0);  // this function is only used in non-interactive mode
+
+   // check for "convert" (ImageMagick)
+  bool imagemagick = false;
+  QString n1, cmd1;
+  n1.setNum( getpid() );
+  n1.prepend("/tmp/");
+  cmd1 = "convert > " + n1;
+  system( cmd1.ascii() );
+  
+  QFile f1( n1 );
+  f1.open(IO_ReadOnly);
+  f1.readLine(cmd1, 256);
+
+  if (cmd1.contains("ImageMagick") > 0) {
+    std::cout << "ImageMagick is present" << std::endl;
+    imagemagick = true;
+  }
+
+  cmd1 = "rm " + n1;
+  system( cmd1.ascii() );
+
+  QPixmap tosave;
+  tosave = r->MakePixmap( ni_tflag );
+  QString sizehint;
+  n1.setNum( tosave.width() );
+  sizehint = n1;
+  sizehint.append("x");
+  n1.setNum( tosave.height() );
+  sizehint.append(n1);
+ if (imagemagick) {
+    n1 = ni_savefile;
+    n1.append(".eps");
+    r->SaveEPS(n1);
+    cmd1 = "convert -antialias -size " +sizehint + " " + n1 + " -resize " 
+      + sizehint + " " + ni_savefile;
+    system( cmd1.ascii() );
+    cmd1 = "rm " + n1;
+    system( cmd1.ascii() );
+    was_saved = true;
+  } else {
+    was_saved = tosave.save(ni_savefile, "PNG");
+  }
+  
+  //QPixmap tosave = r->MakePixmap( ni_tflag );
+  //was_saved = tosave.save(ni_savefile, "PNG");
+  if (was_saved == false) std::cout << "save PNG failed" << std::endl;
+  close();  // this function is only used in non-interactive mode
 }
 
 void ApplicationWindow::Save3D() {
   bool was_saved;
   c->Save3D( ni_savefile );
-  exit(0);  // this function is only used in non-interactive mode
+  close();  // this function is only used in non-interactive mode
 }
 
 void ApplicationWindow::print()
@@ -1540,7 +1648,7 @@ void ApplicationWindow::HelpTopic(QString topic) {
 
 // new manual (based on QTextBrowser) -- derived from Qt example "helpviewer"
 /****************************************************************************
-** $Id: application.cpp,v 1.34 2005/03/22 05:42:53 bherger Exp $
+** $Id: application.cpp,v 1.44 2005/07/10 01:32:44 bherger Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -1583,6 +1691,7 @@ void ApplicationWindow::CalcpKa() { r->Tool(MODE_TOOL_PKA); }
 void ApplicationWindow::CalcKOW() { r->Tool(MODE_TOOL_KOW); }
 void ApplicationWindow::CalcName() { r->Tool(MODE_TOOL_NAME); }
 void ApplicationWindow::ToSMILES() { r->Tool(MODE_TOOL_TOSMILES); }
+void ApplicationWindow::ToInChI() { r->Tool(MODE_TOOL_TOINCHI); }
 void ApplicationWindow::To3D() { r->Tool(MODE_TOOL_2D3D); }
 void ApplicationWindow::CleanUpMolecule() { r->Tool(MODE_TOOL_CLEANUPMOL); }
 void ApplicationWindow::saveCustomRing() { r->Tool(MODE_TOOL_CUSTOMRING); }
