@@ -109,6 +109,7 @@ extern Preferences preferences;
 #define FG_DABSYL 503
 #define FG_DANSYL 504
 #define FG_EDANS 505
+#define FG_BIOTIN 506
 // end structures
 
 QPopupMenu *ApplicationWindow::BuildNewRingMenu() {
@@ -341,6 +342,9 @@ QPopupMenu *ApplicationWindow::BuildNewRingMenu() {
   fgSub->insertItem( tr("[*] EDANS"),
 		     this, SLOT(FromNewRingMenu(int)), 0,
 		     FG_EDANS);
+  fgSub->insertItem( tr("[*] Biotin"),
+		     this, SLOT(FromNewRingMenu(int)), 0,
+		     FG_BIOTIN);
   ringSub->insertItem( tr("Useful groups"), fgSub );
 
   // make user-defined list
@@ -431,6 +435,7 @@ void ApplicationWindow::FromNewRingMenu(int x) {
   if (x == FG_DABSYL) fname = "dabsyl.cml";
   if (x == FG_DANSYL) fname = "dansyl.cml";
   if (x == FG_EDANS) fname = "edans.cml";
+  if (x == FG_BIOTIN) fname = "biotin.cml";
   //c->load( RingDir + fname );
   //r->Inserted();
   if (fname == "cyclopropane.cml") {
@@ -489,6 +494,10 @@ void ApplicationWindow::FromNewRingMenu(int x) {
     r->setMode_DrawRing(RingDir + fname, fname.left(fname.length() - 4), 2);
     return;
   }
+  if (fname == "biotin.cml") {
+    r->setMode_DrawRing(RingDir + fname, fname.left(fname.length() - 4), 2);
+    return;
+  }
   if ( (x > 299) && (x < 350) ) {
     r->setMode_DrawRing(RingDir + fname, fname.left(fname.length() - 4), 3);
     return;
