@@ -4,7 +4,7 @@
 #define CHEMDATA_H
 
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstringlist.h>
 
 #include "drawable.h"
@@ -54,8 +54,8 @@ class ChemData : public QObject {
   void SetColorIfHighlighted(QColor);
   void FinishMove();
   QRect selectionBox();
-  QList<DPoint> UniquePoints();
-  QList<Drawable> UniqueObjects();
+  QPtrList<DPoint> UniquePoints();
+  QPtrList<Drawable> UniqueObjects();
   void SetTopLeft(QPoint p) { RenderTopLeft = p; }
   Molecule *insideMolecule(DPoint *);
   // defined in chemdata_edit.cpp
@@ -113,6 +113,7 @@ class ChemData : public QObject {
   // defined in retro.cpp
   void Retro(Molecule *);
   // defined here
+  void setThickKludge(int lt1) { thick_kludge = lt1; }
   Clipboard *getClipboard() { return clip; }
   void setClipboard(Clipboard *clip1) {
     if (clip1 == 0)
@@ -139,16 +140,16 @@ class ChemData : public QObject {
   // temporary/current Drawable (temporary DPoint *tmp_pt defined below)
   Drawable *tmp_draw;
   // list of Drawable objects we are tracking
-  QList<Drawable> drawlist;
+  QPtrList<Drawable> drawlist;
   // Variables for reading CML/CDXML/XML files
   QString MoleculeTitle;
   QString MoleculeId;
-  QList<CML_Atom> CML_Atoms;
-  QList<CML_Atom> CML_Atoms_Sub;
-  QList<CML_Bond> CML_Bonds;
-  QList<CML_Bond> CML_Bonds_Sub;
-  QList<int> TagStack;
-  QList<Drawable> CDXML_Objects;
+  QPtrList<CML_Atom> CML_Atoms;
+  QPtrList<CML_Atom> CML_Atoms_Sub;
+  QPtrList<CML_Bond> CML_Bonds;
+  QPtrList<CML_Bond> CML_Bonds_Sub;
+  QPtrList<int> TagStack;
+  QPtrList<Drawable> CDXML_Objects;
   DPoint *tmp_pt;
   CML_Atom *tmp_atom;
   CML_Bond *tmp_bond;
@@ -161,6 +162,8 @@ class ChemData : public QObject {
   // Presistent dialogs
   MolInfoDialog *mi;
   Text *tt, *tt_mw, *tt_ef, *tt_ea;
+  // hack for setting ring thickness
+  int thick_kludge;
 };
 
 #endif
