@@ -1,8 +1,10 @@
 #include <iostream>
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qmessagebox.h>
 #include <qregexp.h>
+#include <qapplication.h>
+#include <qclipboard.h>
 
 using std::cout;
 using std::endl;
@@ -28,7 +30,7 @@ using std::endl;
 class LayoutGroup {
 public:
   Drawable *tmp_draw;
-  QList<Drawable> items;
+  QPtrList<Drawable> items;
   LayoutGroup *left;
   LayoutGroup *right;
   LayoutGroup *above;
@@ -66,6 +68,8 @@ public:
 
 // Determine Molecule clicked, do Tool action
 void ChemData::Tool(DPoint *target, int mode) {
+  QClipboard *cb = QApplication::clipboard();
+
   std::cout << "ChemData::Tool: " << mode << std::endl;
   Molecule *m = 0;
   NetAccess na;
@@ -78,6 +82,7 @@ void ChemData::Tool(DPoint *target, int mode) {
   QString tmpname, serverName;
   QStringList choices;
   Bond *tmp_bond;
+  int dret;
 
   for (tmp_draw = drawlist.first(); tmp_draw!=0; tmp_draw = drawlist.next()) {
     if (tmp_draw->Type() == TYPE_MOLECULE) {
@@ -101,9 +106,11 @@ void ChemData::Tool(DPoint *target, int mode) {
     serverName = getenv("XDC_SERVER");
     if (serverName.length() < 2)
       serverName = XDC_SERVER;
-    if (na.getNameCAS(serverName, m->CalcName())) {
+    if (na.getNameCAS(serverName, m->ToSMILES())) {
       mi->setCAS(na.scas);
-      mi->setName(na.sname);
+      mi->setName(na.siupacname);
+      mi->setSynonyms(na.sname);
+      mi->setPCC(na.spccompound);
     }
 
     connect( mi, SIGNAL(MIDClose()), this, SLOT(returnFromMID()) );
@@ -192,6 +199,19 @@ void ChemData::Tool(DPoint *target, int mode) {
     }
     QMessageBox::information(r, tr("SMILES string"), tr("SMILES string for selected molecule:") + "\n\n" + tmpname);
     break;
+  case MODE_TOOL_TOINCHI:
+    //m->AddNMRprotons();
+    tmpname = m->ToSMILES();
+    //m->RemoveNMRprotons();
+    if ( na.runInChI( tmpname ) ) {
+      dret = QMessageBox::information( r, tr("InChI string"), tr("InChI string for selected molecule:") + "\n\n" + na.fullinchi, tr("OK"), tr("Copy to clipboard") );
+      if (dret == 1) {
+	cb->setText(na.shortinchi.mid(6), QClipboard::Selection);
+      }
+    } else {
+      emit SignalSetStatusBar( tr("Could not convert to InChI string.") );
+    }
+    break;
   case MODE_TOOL_CLEANUPMOL:
     m->CleanUp();
     break;
@@ -257,7 +277,7 @@ void ChemData::clearAllGroups() {
 // calculate molecular weights of Molecules
 // AutoLayout
 void ChemData::AutoLayout() {
-  QList<LayoutGroup> layout;
+  QPtrList<LayoutGroup> layout;
   LayoutGroup *tmp_lo, *tl, *tr, *ta, *tb, *tl1;
   int dista, distb, distl, distr, d1, d2, d3, d4, ds;
   Text *tmp_text;
@@ -331,7 +351,7 @@ void ChemData::AutoLayout() {
     } // if (...TYPE_ARROW)
   } // for(...)
   // Now determine position of LayoutGroups
-  QListIterator<LayoutGroup> it(layout);
+  QPtrListIterator<LayoutGroup> it(layout);
   for (tmp_lo = layout.first(); tmp_lo != 0; tmp_lo = layout.next()) {
     QRect box = tmp_lo->BoundingBox();
     QPoint l1(box.left(), box.center().y());
@@ -478,7 +498,7 @@ void ChemData::SmartPlace(QString sf, DPoint *t1) {
   dx = t1->x - tmp_pt->x;
   dy = t1->y - tmp_pt->y;
   m1->Move(dx, dy);
-  QList<DPoint> nb = m1->BreakRingBonds(tmp_pt);
+  QPtrList<DPoint> nb = m1->BreakRingBonds(tmp_pt);
   for (tmp_pt = nb.first(); tmp_pt != 0; tmp_pt = nb.next() ) {
     addBond(tmp_pt, t1, 1, tmp_pt->new_order, QColor(0,0,0), true);
     cout << "added a bond" << endl;
@@ -498,7 +518,7 @@ void ChemData::SmartPlaceToo(QString sf, DPoint *t1) {
   dx = t1->x - tmp_pt->x;
   dy = t1->y - tmp_pt->y;
   m1->Move(dx, dy);
-  QList<DPoint> nb = m1->BreakRingBonds(tmp_pt);
+  QPtrList<DPoint> nb = m1->BreakRingBonds(tmp_pt);
   for (tmp_pt = nb.first(); tmp_pt != 0; tmp_pt = nb.next() ) {
     addBond(tmp_pt, t1, 1, tmp_pt->new_order, QColor(0,0,0), true);
     cout << "added a bond" << endl;
@@ -528,7 +548,7 @@ void ChemData::SmartPlaceThree(QString sf, DPoint *t1) {
   dx = t1->x - tmp_pt->x;
   dy = t1->y - tmp_pt->y;
   m1->Move(dx, dy);
-  QList<DPoint> nb = m1->BreakRingBonds(tmp_pt);
+  QPtrList<DPoint> nb = m1->BreakRingBonds(tmp_pt);
   for (tmp_pt = nb.first(); tmp_pt != 0; tmp_pt = nb.next() ) {
     addBond(tmp_pt, t1, 1, tmp_pt->new_order, QColor(0,0,0), true);
     cout << "added a bond" << endl;
@@ -573,7 +593,7 @@ bool ChemData::SelectWithinLoop(QPointArray tmp_lasso) {
   QPoint tmp_bb;
   DPoint *t1, *t2;
 
-  QList<Drawable> obj_list = UniqueObjects();
+  QPtrList<Drawable> obj_list = UniqueObjects();
   retval = false;
   
   for (tmp_draw = obj_list.first(); tmp_draw != 0; 
