@@ -6,7 +6,7 @@
 #include <qobject.h>
 #include <qrect.h>
 #include <qcolor.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include "dpoint.h"
 class Bond;
 class Text;
@@ -37,8 +37,8 @@ class Drawable : public QObject {
   virtual void Flip(DPoint *, int);
   virtual void Resize(DPoint *, double);
   virtual QRect BoundingBox();
-  virtual QList<DPoint> AllPoints();
-  virtual QList<Drawable> AllObjects();
+  virtual QPtrList<DPoint> AllPoints();
+  virtual QPtrList<Drawable> AllObjects();
   virtual QString ToXML(QString);
   virtual QString ToCDXML(QString);
   virtual void FromXML(QString);
