@@ -4,7 +4,7 @@
 #define MOLECULE_H
 
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <iostream>
 using std::cout;
 using std::endl;
@@ -61,10 +61,10 @@ class Molecule : public Drawable {
   void Resize(DPoint *, double);
   QRect BoundingBox();
   QRect BoundingBoxAll();
-  QList<DPoint> AllPoints();
-  QList<Drawable> AllObjects();
-  QList<Bond> AllBonds();
-  QList<Molecule> MakeSplit();
+  QPtrList<DPoint> AllPoints();
+  QPtrList<Drawable> AllObjects();
+  QPtrList<Bond> AllBonds();
+  QPtrList<Molecule> MakeSplit();
   int Members() { return bonds.count(); }
   QString ToXML(QString);
   QString ToCDXML(QString);
@@ -75,7 +75,7 @@ class Molecule : public Drawable {
   Bond * FindBond(DPoint *, DPoint *);
   int OrderOfBond(DPoint *, DPoint *);
   void Reactivity(int);  // molecule_tools_2.cpp for now
-  QList<DPoint> BreakRingBonds(DPoint *);
+  QPtrList<DPoint> BreakRingBonds(DPoint *);
   DPoint *GetRingAttachPoint();
   DPoint *GetAttachPoint(QString);
   double CalculateRingAttachAngle(DPoint *);
@@ -181,21 +181,21 @@ class Molecule : public Drawable {
   // current/temporary DPoint
   DPoint *tmp_pt;
   // list of elements which make up this molecule
-  QList<Bond> bonds;
-  QList<Text> labels;
-  QList<Symbol> symbols;
+  QPtrList<Bond> bonds;
+  QPtrList<Text> labels;
+  QPtrList<Symbol> symbols;
   // Text objects which hold MW and formula
   Text *text_mw, *text_formula;
   // list of unique points used by Move(), Resize(), Rotate(), and
   // function to fill it
   void MakeTomoveList();
-  QList<DPoint> tomove;
+  QPtrList<DPoint> tomove;
   // used for elemental analysis (set by CalcEmpiricalFormula)
   double nc, nh, no, nn, nmw;
   // Molecule's SSSR
   SSSR this_sssr;
   // point list for SDG, etc.
-  QList<DPoint> up;
+  QPtrList<DPoint> up;
   // group data
   int group_type;
   int group_id;
