@@ -1,7 +1,7 @@
 // molecule_tools_1.cpp - Molecule's implementation of (more) functions
 
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <qmessagebox.h>
 #include <iostream>
@@ -31,7 +31,7 @@ extern Preferences preferences;
 // note that this function builds the DPoint::neighbors list as well
 void Molecule::MakeSSSR() {
   AllNeighbors();
-  QList<DPoint> groupAtoms = AllPoints();
+  QPtrList<DPoint> groupAtoms = AllPoints();
   this_sssr.BuildSSSR(groupAtoms);
   this_sssr.PrintSSSR();
   this_sssr.FindAromatic(bonds);
@@ -78,7 +78,7 @@ QString Molecule::CalcName() {
 QStringList Molecule::Calc13CNMR(bool show_dialog) {
   BremserOneSphereHOSECodePredictor boshcp;
   QStringList hosecodes;
-  QList<DPoint> sphere1;
+  QPtrList<DPoint> sphere1;
   QString tmp_str, ts;
   DPoint *tmp_pt2, *tmp_pt3;
   int hs, hsmax;
@@ -221,7 +221,7 @@ QStringList Molecule::Calc13CNMR(bool show_dialog) {
 }
 
 void Molecule::CalcIR() {
-  QList<DPoint> up;
+  QPtrList<DPoint> up;
   int atom1, atom2, lorder, swp;
 
   // get list of unique points
@@ -233,7 +233,7 @@ void Molecule::CalcIR() {
 
   GraphDialog *g = new GraphDialog(r, tr("Predicted IR"));
   // iterate thru all Bonds in Molecule
-  QListIterator<Bond> outer(bonds), inner(bonds);
+  QPtrListIterator<Bond> outer(bonds), inner(bonds);
   for ( ; outer.current(); ++outer) {
     // check for 'obvious' cases
     tmp_bond = outer.current();
