@@ -21,7 +21,9 @@ void Render2D::Select_mouseMoveEvent(QMouseEvent *e1) {
     tmp_lasso.setPoint(lasso_insert, e1->pos());
     repaint(false);
     directdraw = true;
+    painter->begin(this);
     drawPolyline(tmp_lasso, QColor(0,0,255));
+    painter->end();
     directdraw = false;    
     return;
   }
@@ -172,9 +174,11 @@ void Render2D::Select_mouseMoveEvent(QMouseEvent *e1) {
 		      false);
     repaint(false);
     directdraw = true;
+    painter->begin(this);
     drawBox( zoomCorrectReverse(selectOrigin), 
 	     zoomCorrectReverse(selectPrev), 
 	     QColor(0,0,0));
+    painter->end();
     directdraw = false;
   }
 
