@@ -2,7 +2,7 @@
 #define TOOL_13CNMR_H
 
 #include <qdialog.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 #include <qtextedit.h>
 
