@@ -2,7 +2,7 @@
 #define TOOLDIALOG_H
 
 #include <qdialog.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 
 #include "mol.h"
